# FoLiA examples

This directory contains FoLiA example documents. These examples serve two purposes:

1) As an example of how FoLiA works for human-end users. Note that this is no substitute for the official documentation!
2) As input for automated tests by FoLiA libraries and other FoLiA tools

The numbers in the filenames refer to the FoLiA version used. Once made, the examples should not change.

## Contents

### Deep examples

*Deep examples are examples that refer to proper set definitions for all annotation types and therefore can be validated
on a deep level*

* ``frog-deep.1.3.2.folia.xml`` - Tokenised dutch text with part-of-speech tags, lemmas, named entities, shallow
    parsing, dependency parsing, and morphological analysis. Produced by
    [Frog](https://languagemachines.github.io/frog).

### 'Shallow' examples

*Shallow examples lack a complete set definition for at least one annotation type*

* ``arabic.0.12.folia.xml`` - A small manually-constructed example of some annotated arabic text
* ``corrections.0.12.folia.xml`` - A manually constructed example showing all different kinds of orthographical correction (dutch text)
* ``corrections-valkuil.1.5.1.folia.xml`` - Suggestions for (dutch) spelling correction as produced by [Valkuil](http://valkuil.net)
* ``full-legacy.1.5.folia.xml`` - An extensive example that shows everything FoLiA has to offer up to FoLiA v1.5 in a
    single document. The downside is that this makes the example rather contrived and sometimes non-sensible.
* ``morphology.1.3.2.folia.xml`` - An example of morphology output as generated by Frog (on dutch text)
* ``textvalidation.1.5.0.folia.xml`` - An example document with text redundancy, i.e. text on multiple levels. FoLiA
    libraries are be able to validate the text consistency across the levels since FoLiA v1.5.

### Examples from existing corpora

The following examples are extracted from existing corpora that are delivered in FoLiA XML:

* ``corrections-clin28sharedtask.1.5.1.folia.xml`` - A (dutch) document with manually annotated spelling corrections
    (annotated with [FLAT](https://github.com/proycon/flat)), a gold standard for the CLIN28 Shared Task.
* ``sonar500.0.8.0.folia.xml`` - An example of a (dutch) document from the SoNaR-500 corpus, enriched with PoS, lemmas,
    named entities, and morphology.
* ``speech-opencgn.0.12.1.folia.xml`` - An example of a (dutch) document from the OpenCGN corpus, it is a transcription of speech and includes a phonetic transcription layer and timing information. There are also PoS tags and lemmas.

### Test examples

The directory ``tests/`` holds examples that are used by automated unit and integration tests, most notably for FoLiA
libraries. These tests are all valid FoLiA, but may be less useful to end users as examples.

### Erroneous examples

*Erroneous examples are invalid FoLiA, they serve to either illustrate a bad practice or to use to test error handling.
FoLiA libraries and validators should never accept these documents.*

* ``erroneous/inconsistenttext.1.5.0.folia.xml`` - An example of a document with inconsistent text (i.e. text specified
    on multiple levels is not consistent and therefore the document is invalid).
